@@ -308,6 +308,28 @@ package Cfn::TypeLibrary {
     'List<AWS::EC2::VPC::Id>',
     'AWS::Route53::HostedZone::Id',
     'List<AWS::Route53::HostedZone::Id>',
+    'AWS::SSM::Parameter::Name',
+    'AWS::SSM::Parameter::Value<String>',
+    'AWS::SSM::Parameter::Value<List<String>>',
+    'AWS::SSM::Parameter::Value<CommaDelimitedList>',
+    'AWS::SSM::Parameter::Value<AWS::EC2::AvailabilityZone::Name>',
+    'AWS::SSM::Parameter::Value<AWS::EC2::Image::Id>',
+    'AWS::SSM::Parameter::Value<AWS::EC2::Instance::Id>',
+    'AWS::SSM::Parameter::Value<AWS::EC2::SecurityGroup::GroupName>',
+    'AWS::SSM:;Parameter::Value<AWS::EC2::SecurityGroup::Id>',
+    'AWS::SSM::Parameter::Value<AWS::EC2::Subnet::Id>',
+    'AWS::SSM::Parameter::Value<AWS::EC2::Volume::Id>',
+    'AWS::SSM::Parameter::Value<AWS::EC2::VPC::Id>',
+    'AWS::SSM::Parameter::Value<AWS::Route53::HostedZone::Id>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::AvailabilityZone::Name>>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::Image::Id>>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::Instance::Id>>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::SecurityGroup::GroupName>>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::SecurityGroup::Id>>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::Subnet::Id>>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::Volume::Id>>',
+    'AWS::SSM::Parameter::Value<List<AWS::EC2::VPC::Id>>',
+    'AWS::SSM::Parameter::Value<List<AWS::Route53::HostedZone::Id>>',
   ];
 
   subtype 'ArrayOfCfn::Resource::Properties::TagType',
@@ -882,7 +904,7 @@ package Cfn {
   has Description => (isa => 'Str', is => 'rw');
   has Transform => (isa => 'Cfn::Transform', is => 'rw', coerce => 1);
 
-  our $VERSION = '0.05';
+  our $VERSION = '0.06';
 
   has Parameters => (
     is => 'rw',
@@ -1154,6 +1176,26 @@ package Cfn {
     require JSON;
     return $class->from_hashref(JSON::from_json($json));
   }
+
+  sub _get_yaml_pp {
+    require YAML::PP;
+    YAML::PP->new(
+      schema => [ ':Cfn::YAML::Schema' ],
+    );
+  }
+
+  has yaml => (is => 'ro', lazy => 1, default => \&_get_yaml_pp);
+
+  sub as_yaml {
+    my $self = shift;
+    return $self->yaml->dump_string($self);
+  }
+
+  sub from_yaml {
+    my ($class, $yaml) = @_;
+    my $parser = _get_yaml_pp;
+    return $class->from_hashref($parser->load_string($yaml));
+  }
 }
 
 package Cfn::MutabilityTrait {
@@ -1181,9 +1223,10 @@ Cfn - An object model for CloudFormation documents
 
 =head1 DESCRIPTION
 
-This module helps parse, manipulate and validate CloudFormation documents. It creates
-an object model of a CloudFormation template so you can work with the document as 
-a set of objects. See L<https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-anatomy.html> for
+This module helps parse, manipulate, validate and generate CloudFormation documents in JSON
+and YAML formats (see stability section for more information on YAML). It creates an object 
+model of a CloudFormation template so you can work with the document as a set of objects. 
+See L<https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-anatomy.html> for
 more information.
 
 It provides full blown objects for all know CloudFormation resources. See 
@@ -1223,7 +1266,11 @@ This method converts a hashref that represents a CloudFormation document into a
 
 =head3 from_json
 
-This method creates a Cfn object from a JSON string that containes a CloudFormation document
+This method creates a Cfn object from a JSON string that contains a CloudFormation document in JSON format
+
+=head3 from_yaml
+
+This method creates a Cfn object from a YAML string that contains a CloudFormation document in YAML format
 
 =head2 Attributes
 
@@ -1239,6 +1286,12 @@ You can specify your own JSON serializer to control how JSON is generated:
   ...
   print $cfn->as_json;
 
+=head3 yaml
+
+Holds a configured C<YAML::PP> parser for use when serializing and deserializing to and from YAML.
+Methods C<load_string> and C<dump_string> are called when needed from convert the object model
+to a YAML document, and to convert a YAML document to a datastructure that can later be coerced
+into the object model.
 
 =head3 cfn_options
 
@@ -1344,7 +1397,11 @@ called with the C<$cfn> instance as the first parameter to their subroutine
 
 =head3 as_json
 
-Returns a JSON representation of C<as_hashref>. Just a shortcut
+Returns a JSON representation of the current instance
+
+=head3 as_yaml
+
+Returns a YAML representation of the current instance
 
 =head3 path_to($path)
 
@@ -1775,6 +1832,12 @@ Holds a HashRef with the export definition of the object
 
 Returns a HashRef representation of the output that is convertible to JSON
 
+=head1 STABILITY
+
+YAML support is recent, and due to the still evolving YAML::PP module, may break 
+(altough the tests are there to detect that). This distribution will try to keep up 
+as hard as it can with latest YAML::PP developments.
+
 =head1 SEE ALSO
 
 L<https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-anatomy.html>
@@ -1792,6 +1855,10 @@ This module kind of resembles troposphere (python): L<https://github.com/cloudto
 Thanks to Sergi Pruneda, Miquel Ruiz, Luis Alberto Gimenez, Eleatzar Colomer, Oriol Soriano, 
 Roi Vazquez for years of work on this module.
 
+TINITA for helping make the YAML support possible. First for the YAML::PP module, which is the only
+Perl module to support sufficiently modern YAML features, and also for helping me in the use of
+YAML::PP.
+
 =head1 BUGS and SOURCE
 
 The source code is located here: L<https://github.com/pplu/cfn-perl>
